@@ -1,8 +1,8 @@
 """
-scaffoldgraph tests.analysis.test_representation
+scaffoldgraphnew tests.analysis.test_representation
 """
 
-from scaffoldgraph.analysis import calc_average_pairwise_similarity, get_over_represented_scaffold_classes
+from scaffoldgraphnew.analysis import calc_average_pairwise_similarity, get_over_represented_scaffold_classes
 from ..test_network import long_test_network
 
 
