@@ -1,11 +1,11 @@
 """
-scaffoldgraph tests.test_tree
+scaffoldgraphnew tests.test_tree
 """
 
 import networkx as nx
 import pytest
 
-import scaffoldgraph as sg
+import scaffoldgraphnew as sg
 
 from . import mock_sdf, mock_smiles_file
 
