@@ -1,5 +1,5 @@
 """
-scaffoldgraph tests.utils
+scaffoldgraphnew tests.utils
 """
 
 from .. import mock_sdf, mock_sdf_2
